"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeSearchCmd = void 0;
const os = __importStar(require("os"));
const output_formatting_1 = require("./output-formatting");
const ts_results_es_1 = require("ts-results-es");
/**
 * Makes a {@link SearchCmd} function.
 */
function makeSearchCmd(parseEnv, searchRegistry, getAllPackuments, log) {
    function searchEndpoint(registry, keyword) {
        return searchRegistry(registry, keyword).map((results) => {
            log.verbose("npmsearch", results.join(os.EOL));
            return results;
        });
    }
    function searchOld(registry, keyword) {
        return getAllPackuments(registry).map((allPackuments) => {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            const { _updated, ...packumentEntries } = allPackuments;
            const packuments = Object.values(packumentEntries);
            log.verbose("endpoint.all", packuments.join(os.EOL));
            // filter keyword
            const klc = keyword.toLowerCase();
            return packuments.filter((packument) => packument.name.toLowerCase().includes(klc));
        });
    }
    return async (keyword, options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr())
            return envResult;
        const env = envResult.value;
        // search endpoint
        let result = await searchEndpoint(env.registry, keyword).promise;
        // search old search
        if (result.isErr()) {
            log.warn("", "fast search endpoint is not available, using old search.");
            result = await searchOld(env.registry, keyword).promise;
        }
        if (result.isErr()) {
            log.warn("", "/-/all endpoint is not available");
            return result;
        }
        const results = result.value;
        if (results.length === 0) {
            log.notice("", `No matches found for "${keyword}"`);
            return (0, ts_results_es_1.Ok)(undefined);
        }
        console.log((0, output_formatting_1.formatAsTable)(results));
        return (0, ts_results_es_1.Ok)(undefined);
    };
}
exports.makeSearchCmd = makeSearchCmd;
//# sourceMappingURL=cmd-search.js.map