"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logPackumentResolveError = exports.logManifestSaveError = exports.logManifestLoadError = void 0;
const file_io_1 = require("../io/file-io");
const common_errors_1 = require("../common-errors");
const packument_1 = require("../domain/packument");
/**
 * Logs a {@link ManifestLoadError} to the console.
 */
function logManifestLoadError(log, error) {
    const prefix = "manifest";
    if (error instanceof file_io_1.NotFoundError)
        log.error(prefix, `manifest at ${error.path} does not exist`);
    else {
        log.error(prefix, `failed to parse manifest at ${error.path}`);
        if (error.cause !== undefined)
            log.error(prefix, error.cause.message);
    }
}
exports.logManifestLoadError = logManifestLoadError;
/**
 * Logs a {@link ManifestWriteError} to the console.
 */
function logManifestSaveError(log, error) {
    const prefix = "manifest";
    log.error(prefix, "can not write manifest json file");
    log.error(prefix, error.message);
}
exports.logManifestSaveError = logManifestSaveError;
/**
 * Logs a {@link PackumentResolveError} to the console.
 */
function logPackumentResolveError(log, packageName, error) {
    if (error instanceof common_errors_1.PackumentNotFoundError)
        log.error("404", `package not found: ${packageName}`);
    else if (error instanceof packument_1.VersionNotFoundError) {
        const versionList = [...error.availableVersions].reverse().join(", ");
        log.warn("404", `version ${error.requestedVersion} is not a valid choice of: ${versionList}`);
    }
}
exports.logPackumentResolveError = logPackumentResolveError;
//# sourceMappingURL=error-logging.js.map